package com.yinet.yyqh.mapper;

import com.yinet.yyqh.domain.YyqhGuidance;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 菜单表 数据层
 *
 * @author ruoyi
 */
public interface YyqhGuidanceMapper {
    public List<YyqhGuidance> selectGuidanceList();

    public YyqhGuidance selectGuidanceById(Long id);

    public int updateGuidance(@Param("guidance") YyqhGuidance guidance);

    public int insertGuidance(@Param("guidance") YyqhGuidance guidance);

    public int selectCountGuidanceByParentId(@Param("parentId") Long parentId);

    public int deleteGuidanceById(@Param("guidanceId") Long guidanceId);

    public List<YyqhGuidance> selectParentGuidanceList();

    public YyqhGuidance selectGuidanceByName(@Param("guidanceName") String Name);

    public List<YyqhGuidance> selectGuidanceByParentId(@Param("parentId") Long parentId);

    public List<YyqhGuidance> selectGuidanceNotParentId(@Param("parentId") Long parentId);
}
